<?php
/*Array
(
    [0] => 10108771
    [1] => BECKER
[2] => LOUISE
[3] => BONAITI HACHUEL JAKOB
[4] => 3P
[5] => AVULLY
[6] => BONAIT*/

if ( ! function_exists('array_group_by') ) :
    /**
     * Groups an array by a given key.
     *
     * Groups an array into arrays by a given key, or set of keys, shared between all array members.
     *
     * Based on {@author Jake Zatecky}'s {@link https://github.com/jakezatecky/array_group_by array_group_by()} function.
     * This variant allows $key to be closures.
     *
     * @param array $array   The array to have grouping performed on.
     * @param mixed $key,... The key to group or split by. Can be a _string_,
     *                       an _integer_, a _float_, or a _callable_.
     *
     *                       If the key is a callback, it must return
     *                       a valid key from the array.
     *
     *                       ```
     *                       string|int callback ( mixed $item )
     *                       ```
     *
     * @return array|null Returns a multidimensional array or `null` if `$key` is invalid.
     */

    function array_group_by( array $array, $key )
    {
        if ( ! is_string( $key ) && ! is_int( $key ) && ! is_float( $key ) && ! is_callable( $key ) ) {
            trigger_error( 'array_group_by(): The key should be a string, an integer, or a callback', E_USER_ERROR );
            return null;
        }

        $func = ( is_callable( $key ) ? $key : null );
        $_key = $key;

        // Load the new array, splitting by the target key
        $grouped = [];
        foreach ( $array as $value ) {
            if ( is_callable( $func ) ) {
                $key = call_user_func( $func, $value );
            }
            else {
                $key = $value[ $_key ];
            }

            $grouped[ $key ][] = $value;
        }

        // Recursively build a nested grouping if more parameters are supplied
        // Each grouped array value is grouped according to the next sequential key
        if ( func_num_args() > 2 ) {
            $args = func_get_args();

            foreach ( $grouped as $key => $value ) {
                $params = array_merge( [ $value ], array_slice( $args, 2, func_num_args() ) );
                $grouped[ $key ] = call_user_func_array( 'array_group_by', $params );
            }
        }

        return $grouped;
    }
endif;


if (isset($_GET['ecole'])) {
    $ecole = $_GET['ecole'];
    $ecole_file = "pmb/" . $ecole.".csv";
}else{
	exit("Mauvaise Ecole");
    // Fallback behaviour goes here
}



$result = array();
$file = fopen($ecole_file, 'r');
while (($line = fgetcsv($file,null,';')) !== FALSE) {
    //$line is an array of the csv elements
    array_push($result,$line);
}


require('BarcodeGenerator.php');
require('BarcodeGeneratorPNG.php');


$today=date('j-m-y');
$grouped = array_group_by($result,"3");

//print_r($grouped);

echo "<html><head></head><title>".$ecole." PMB</title></head><body>";


foreach ($grouped as $prof)
{
    //print_r($prof);
    //echo "<div style='page-break-after:always;'>";
    
    echo "<table style='page-break-after:always;' border='0'>";
    echo "<tr bgcolor='' border='0' height='50px'><td colspan='2' style='color:black;font-weight: bolder;'>Classe : ".$prof[0][3]."</td><td style='color:black;font-weight: bolder;' align='right'>".$ecole ." ". $today ."</td></tr>";
    echo "<tr><td>CodeBarre</td><td>Nom</td><td>Prenom</td></tr>";
    echo "<tr bgcolor='black' border='0'><td colspan='3'></td></tr>";
    foreach ($prof as $elv){
        echo "<tr>";

	$generator = new \Picqer\Barcode\BarcodeGeneratorPNG();
	 echo '<td width="150px" align="center"><img src="data:image/png;base64,' . base64_encode($generator->getBarcode($elv[0], $generator::TYPE_CODE_128,'1')) . '"><br>' . $elv[0]. '</td>';
        //echo "<td width='150px'><img alt='testing' src='barcode.php?print=true&size=25&codetype=Code39&text=".$elv[0]."' /></td>";
        echo "<td width='400px'>".$elv[1]."</td>";
        echo "<td width='400px'>".$elv[2]."</td>";
        echo "</tr>";
	echo "<tr bgcolor='black' border='0'><td colspan='3'></td></tr>";
    }
    //echo "<div style='page-break-after:always;'></div>";
    //echo $value['1'];
    echo "</div></table>";
}
echo "</body></html>";
fclose($file);


